==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/include/win/WSDwinFontSelect.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSDWINFONTSELECT_H
#define WSDWINFONTSELECT_H
#include <WScom.h>
#include <WSDappDev.h>
#include <WSCbaseDialog.h>

class WSCform;
class WSCvbtn;
class WSCvlabel;
class WSCoption;

class WSDwinFontSelect :public WSCbaseDialog {
  private:
  LOGFONT _lgfont;
  char*    _font_name;
  void*    _rep;
  unsigned _font_no:4;
  protected:

  WSMFpropertyDef(WSNfontName,char*,_font_name);
  WSMFpropertyDef(WSNfont,WSCuchar,_font_no);


  public:

  virtual long initialize();


  virtual void onVisibleChange(WSCbool);
  virtual long popup();

  WSDwinFontSelect(WSCbase* base,char* name);
  virtual ~WSDwinFontSelect();

  WSMFguiClassDef(WSDwinFontSelect,WSCwindow);
};
#endif

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/win/WSDwinFontSelect.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSDWINFONTSELECT_H
#define WSDWINFONTSELECT_H
#include <WScom.h>
#include <WSDappDev.h>
#include <WSCbaseDialog.h>

class WSCform;
class WSCvbtn;
class WSCvlabel;
class WSCoption;

class WSDwinFontSelect :public WSCbaseDialog {
  private:
  LOGFONT _lgfont;
  char*    _font_name;
  char*    _target_name;
  void*    _rep;
  unsigned _font_no:4;
  protected:

  WSMFpropertyDef(WSNfontName,char*,_font_name);
  WSMFpropertyDef(WSNtype,char*,_target_name);
  WSMFpropertyDef(WSNfont,WSCuchar,_font_no);


  public:

  WSDLEX32 virtual long initialize();


  WSDLEX32 virtual void onVisibleChange(WSCbool);
  WSDLEX32 virtual long popup();

  WSDLEX32 WSDwinFontSelect(WSCbase* base,char* name);
  WSDLEX32 virtual ~WSDwinFontSelect();

  WSMFguiClassDef(WSDwinFontSelect,WSCwindow);
};
#endif
